div#networkCanvas{
	width:100%;
}
#networkCanvas svg.nodeCanvas {
width: 100%;
}
.change{
	position: absolute;
	bottom: 0; 
	left:50%;
	margin-left:-50%;
}
.waitingGIF{margin-top: 20%;}

.statSelect{
	margin-top: 15px;
	font-family: 'Raleway',sans-serif;
	font-size: 14px;
	float:right;
	visibility:hidden;
}
.statSelect select{
	background-color: white;
	border:1px solid black;
}

div.modal-dialog{
  margin-top: 50px;
}
.sliderContainer{
	font-size: 10px;
	font-family: 'Raleway',sans-serif;
	margin-top: 3px;
	text-align: center;
	padding-left: 8px;
	visibility: hidden;
}
.slider{
	width:100px;
	font-size: 12px;
	margin-left: 39px;
	
}

.btn.info{
  padding: 0px 4px;
  line-height: 18px;
  border-radius: 3px;
  margin-top: -2px;
  font-weight: bold;
  border: 1px solid;
}

.ui-widget-header{
	background:#8AA37B;
}

.ui-state-hover, .ui-widget-content .ui-state-hover, .ui-widget-header .ui-state-hover, .ui-state-focus, .ui-widget-content .ui-state-focus, .ui-widget-header .ui-state-focus {
border: 1px solid #333;
background: white url("images/ui-bg_glass_100_fdf5ce_1x400.png") 50% 50% repeat-x;
font-weight: bold;
color: #888
}













@media (max-width: 550px){
	#networkCanvas {
		display: inline;
	}
}