@import url(http://fonts.googleapis.com/css?family=Carter+One|Special+Elite|Raleway);


h1{
	font-size: 70px;
	padding-left: 20px;
}
h2{
	font-size:45px;
}
h5{
	font-size: 24px;
}

.clickable{
	padding:4px 25px 0px;
}

.waitingGIF{
	display: block;
	margin:50px auto;
	vertical-align: middle;
}
#networkCanvas{
	height:250px;
}
.fullMap{
	font-size: 12px;
	font-family: 'Raleway',sans-serif;
	text-align: right;
	padding-right: 10%;
	font-style: italic;
	
}
.fullMap a{
	color:#999;
}

.professional{
text-align: left;
font-size: 14px;
color: #333;
font-family: 'Raleway',sans-serif;
line-height: 18px;
padding-left: 20px;
}

.professional span{
	font-weight: bold;
	font-size: 16px;
	color:#8C1717;
}
.entity_notes{
font: 14px 'Raleway',sans-serif;
max-width: 500px;
text-align: left;
padding-left: 20px;
margin-top: 15px;
}

.bioBank{
	margin:0 auto;
	text-align:left;
	padding-left: 20px;
}

.change{
	text-align: center;
	font-family: 'Raleway', sans-serif;
	font-size: 20px;
	margin-top: 15px;
}
.change a{
	margin:10px 10px 0px;
	color:#888;
}
.change a:hover{
	color:#880000;
	text-decoration: none;
}

#peepPosition{
	padding:0px 10px;
	text-align: left;
	height:50px;
	display:block;
}
#networkCanvas{
	width:500px;
	margin:0 auto;
	float:left;
}
#networkCanvas svg.nodeCanvas{
	width:500px;
	margin:0 auto;
}

.contact_role{
	font-family: 'Raleway', sans-serif;
	font-size: 10px;
	font-style: italic;
	padding-left:25px;
	width:100%;
	margin-top: -2px;
}

.bioBank h6{
	text-align: center;
	font-family:'Montserrat',serif;
	color:#333;
	font-size: 18px;
	text-decoration: underline;
	margin-top: 10px;
	margin-bottom: 0px;
}

.bioBank ul{
	list-style-type: none;
	font-family:'Raleway',sans-serif;
}
.bioBank li{
	font-size: 16px;
	color:black;
}
.bioBank li .type{
	color: #333;
	font-size: 16px;
	margin-right: 5px;
}
.bioBank li.notes{
	color: #333;
	font-size: 12px;
	padding-left: 25px;
}
.bioBank .relation_container{
	max-width:500px;
	text-align: left;
}

.bioBank .relation_container i.fa.fa-user {
	padding:0px 4px 0px 3px;
}

.bioBank .relations{
	font-family: 'Raleway', sans-serif;
	font-size: 10px;
	font-style: italic;
	display:inline-block;
}
.bioBank .relations span{
	font-size: 18px;
	font-style: normal;
}
.bioBank .relations span a{
	color:#36788e;
	font-weight: normal;
}
.bioBank .relations span a:hover{
	text-decoration: none;
	font-weight: bolder;
}
.bioBank .relations .relation_type{
	padding-left:25px;
	width:100%;
	margin-top: -5px;
}
.bioBank .relations .relation_delete{
	color:lightgrey;
	cursor:pointer;
	font-style: normal;
	margin-left: 5px;
}
.bioBank .relations .relation_delete:hover{
	color:#880000;
}
#networkCanvas{
		display: inline;
	}

.change.delete{
	font-size: 12px;
	margin-top: 50px;
	text-align:right;
}

@media (max-width: 550px){
	#networkCanvas, .fullMap{
		display:none;
	}

}

@media (max-width: 400px) {
	h1{
		font-size: 48px;
		margin-top: 32px;
		margin-bottom: 0px;
	}
	.relation_delete, .change.delete{
		display:none;
	}

	
}
