@import url(https://fonts.googleapis.com/css?family=Special+Elite|IM+Fell+DW+Pica|Montserrat:300,400|Audiowide|Open+Sans);

html, body, div, span, applet, object, iframe,
h1, h2, h3, h4, h5, h6, p, blockquote, pre,
a, abbr, acronym, address, big, cite, code,
del, dfn, em, img, ins, kbd, q, s, samp,
small, strike, strong, sub, sup, tt, var,
b, u, i, center,
dl, dt, dd, ol, ul, li,
fieldset, form, label, legend,
table, caption, tbody, tfoot, thead, tr, th, td,
article, aside, canvas, details, embed, 
figure, figcaption, footer, header, hgroup, 
menu, nav, output, ruby, section, summary,
time, mark, audio, video {
	margin: 0;
	padding: 0;
	border: 0;
	font-size: 100%;
	font: inherit;
	vertical-align: baseline;
}
/* HTML5 display-role reset for older browsers */
article, aside, details, figcaption, figure, 
footer, header, hgroup, menu, nav, section {
	display: block;
}
body {
	line-height: 1;
}
ol, ul {
	list-style: none;
}
blockquote, q {
	quotes: none;
}
blockquote:before, blockquote:after,
q:before, q:after {
	content: '';
	content: none;
}
table {
	border-collapse: collapse;
	border-spacing: 0;
}

h1,h2,h3,h4,h5{
	text-align: left;
	font-family: 'Montserrat', sans-serif;
}
/*#3D5B43;*/
#stickyNav{
	background-color: #36788e;
	z-index: 9999999999999999;
	font-family: 'Audiowide';
	font-size: 30px;
	color:white;
	padding:0px 20px;
	position:fixed; 
	top: 0; 
	left: 0;
	width:100%;
	height:42px;
}

#stickyNav img{
	padding:0px;
	margin-right: 5px;
	margin-top: 7px;
	float:left;
	width:34px;
}
#stickyNav a,#stickyNav a:hover{
	color:white;
	text-decoration: none;
}

#stickyNav #searchNav{
	float:right;
	background-color: rgb(180, 180, 180);
	padding:0px 10px;
	margin-right: -20px;
	cursor:pointer;
}
#stickyNav a#searchNav {
	color:#fff;
	font-family: 'Montserrat', sans-serif;
}
#stickyNav a#searchNav:hover{
	color:#36788e;
}


.body{
	padding:10px 20px;
}


#midrail{
	max-width:500px;
	margin:0 auto;
}

.clickable{
	max-width:500px;
	text-align: left;
	font-size: 36px;
	font-family: 'Montserrat';
	margin:20px auto;
	padding:4px 25px 0px 100px;
	border-radius: 3px;
	cursor:pointer;
	transition: background-color 0.5s ease;
	background-color: #36788e;
	color:white;
}
/*4a7777a*/
.clickable:hover{
	background-color:#8C1717;
	text-decoration: none;
}



.searchbox{
	max-width:450px;
	margin:10px auto;
}
.searchbox a.addLink{
	font-size: 12px;
	font-style: italic;
}
.searchbox a.goLink, .modal-search a.goLink{
	float: right;
	margin-right: 0px;
	width: 100px;
	background-color: white;
	color:black;
	border:1px solid grey;
	border-radius: 5px;
	font-family: 'Montserrat';
	display:block;
	text-align: center;
	font-size: 20px;
	line-height: 25px;
	padding: 4px 15px 0px 13px;
}
.searchbox a.goLink:hover, .searchbox a.goLink:focus,
.modal-search a.goLink:hover, .modal-search a.goLink:focus {
	text-decoration: none;
	background-color: lightgrey;
	border:1px solid grey;
	color:black;
}
.buttonDiv{
	width:100%;
	margin-bottom: 40px;
}


.searchbox .instruct{
	font-size: 14px;
	color:#333;
	font-family: arial, sans-serif;
	margin: 10px 0;
}

.outside.freetext{
	padding:0px 10px;
	margin-bottom: 15px;
	font-family: Arial,sans-serif;
}


/*breadcrumb*/
.breadcrumb-container{
	position:fixed;
	top:42px;
	left:0px;
}
.breadcrumb { 
	list-style: none; 
	overflow: hidden; 
	font: 16px 'Montserrat',Arial, serif;

}
.breadcrumb li { 
	float: left; 
}
.breadcrumb li a {
	color: white;
	text-decoration: none; 
	padding: 0px 0px 0px 45px;
	background: brown;                   /* fallback color */
	background: hsla(0,0%,15%,1); 
	position: relative; 
	display: block;
	float: left;
}
.breadcrumb li a:after { 
	content: " "; 
	display: block; 
	width: 0; 
	height: 0;
	border-top: 50px solid transparent;           /* Go big on the size, and let overflow hide */
	border-bottom: 50px solid transparent;
	border-left: 30px solid hsla(0,0%,15%,1);
	position: absolute;
	top: 50%;
	margin-top: -50px; 
	left: 100%;
	z-index: 2; 
}
.breadcrumb li a:before { 
	content: " "; 
	display: block; 
	width: 0; 
	height: 0;
	border-top: 50px solid transparent;       
	border-bottom: 50px solid transparent;
	border-left: 30px solid white;
	position: absolute;
	top: 50%;
	margin-top: -50px; 
	margin-left: 1px;
	left: 100%;
	z-index: 1; 
}
.breadcrumb li:first-child a {
	padding-left: 10px;
}
.breadcrumb li:nth-child(2) a       { background:        hsla(0,0%,25%,1); }
.breadcrumb li:nth-child(2) a:after { border-left-color: hsla(0,0%,25%,1); }
.breadcrumb li:nth-child(3) a       { background:        hsla(0,0%,35%,1); }
.breadcrumb li:nth-child(3) a:after { border-left-color: hsla(0,0%,35%,1); }
.breadcrumb li:nth-child(4) a       { background:        hsla(0,0%,45%,1); }
.breadcrumb li:nth-child(4) a:after { border-left-color: hsla(0,0%,45%,1); }
.breadcrumb li:nth-child(5) a       { background:        hsla(0,0%,55%,1); }
.breadcrumb li:nth-child(5) a:after { border-left-color: hsla(0,0%,55%,1); }
.breadcrumb li:last-child a {
	font-weight: bold;
	pointer-events: none;
	cursor: default;
	padding-right: 20px;
	border-top-right-radius:2em;
	border-bottom-right-radius:2em;
}
.breadcrumb li a:hover { background: hsla(190,55%,45%,1); }
.breadcrumb li a:hover:after { border-left-color: hsla(190,55%,45%,1) !important; }



.clearfix:after {
	visibility: hidden;
	display: block;
	font-size: 0;
	content: " ";
	clear: both;
	height: 0;
}


.add-btn{
	font-weight: bold;
	font-size: 18px;
}


/*Search modal*/

#search-modal{
	margin-top: 42px;
}
#search-modal .modal-dialog{
	max-width:500px;
	margin-top: 3px;
}
#search-modal .modal-title{
	line-height: 1;
	font-family:'Audiowide',sans-serif;
	font-style: normal;
}


#search-modal .modal-body{
	padding-bottom: 7px;
}

#search-modal a.goLink{
	margin-top: 5px;
	width:80px;
}

#search-modal .modal-header{
	padding: 5px 15px;
}

.switch-candy{
	background-color: lightgrey;
	text-shadow:none;
	border-radius:2px;
	box-shadow: none;
}
.switch-candy a{
	border-radius: 2px;
	background-color: #36788e;
	box-shadow: none;
	background-image: none;
}

.switch-candy input:checked + label {
color: #fff;
text-shadow: none;
}
.switch-toggle input + label{
	cursor:pointer;
}

.modal-search{
	margin-top: 10px;
}

.optgroup-header{
	font-weight: bold;
}
div.optgroup .option{
	padding-left: 20px;
}


.bioBank .change a {
	margin-left: -20px;
}


@media (max-width:540px){
	.clickable{
		padding-left:25px;
	}
	#stickyNav a#searchNav span{
		display:none;
	}
}

@media (max-width: 400px) {
	.clickable{
		font-size: 24px;
		margin:10px auto;
	}
	.searchbox a.goLink, 
	.modal-search a.goLink{
		margin-right: 5px;
	}
}
