h1,h2,h3,h4,h5{
	text-align: left;
	font-family: 'Montserrat', sans-serif;
}
h1{
	font-size: 70px;
	padding-left: 20px;
}
h2{
	font-size:45px;
}
h5{
	font-size: 24px;
}

h4{
	font-family: 'Raleway',sans-serif;
	color:#333;
}

.clickable{
	padding-left:20px;
}
.relationform{
	padding: 0px 5px 0px 20px;
	max-width: 350px;
	font-family: 'Raleway',sans-serif;
}
.relationform .type select{
	max-width:250px;
	min-width: 210px;
}
.relationform .hierarchy select{
	width:180px;
}
.relationform .type, .relationform .hierarchy{
	display:block;
	margin:0 auto;
	max-width:370px;
}
.button{
	background: white;
	border:1px solid black;
	border-radius:2px;
	display:block;
	margin:0 auto;
}

.instruction{
	font-size: 11px;
	line-height: 12px;
	font-family: arial,sans-serif;
	margin:15px 7px 10px;
	padding:5px;
	border-radius:4px;
	background-color: lightgrey;
}

#form-error{
	background-color: #FFCCCC;
	border-radius:4px;
	font-family: 'Raleway', sans-serif;
	font-size: 14px;
	padding:1px 5px;
	margin:0 auto;
	width:250px;
}
#form-error p{
	margin:0px;
	line-height: 14px;
	font-size: 16px;
	padding:5px;
	font-style: italic;

}
#form-error ul{
	margin:0px;
}
#form-error li{
	font-weight: bold;
	text-align: left;
}

select#id_relation{
	width:auto;
	min-width:125px;
}

button.btn.btn-default {
margin-top: 10px;
}

@media (max-width: 400px) {
	h1{
		font-size: 48px;
		margin-top: 32px;
		margin-bottom: 0px;
	}
	h4{
		font-size: 16px;
	}
	.relationform{
		padding-left: 10px;
	}
	
}