.link {
  fill: none;
  stroke: #666;
  stroke-width:1px;
}
.link.primary{
  stroke: #0EBFE9;
  stroke-width: 2.5px;
}
.node circle {
  stroke: #fff;
  stroke-width: 2px;
}
.node.primary circle.circ.primary, .lab.primary{
  fill:#0EBFE9 ;
  font-weight: bold;
}
.lab{
  fill:#888888;
}
circle.org{
  fill:#5F9F9F;
}
circle.person{
  fill:#FF8C69;
}
text{
  font: 10px sans-serif;
  cursor:pointer;
}

text.colorKey{
  font:10px 'Raleway',sans-serif;
}
text.colorKey.title{
  font-size: 10px;
}

text.centralityData{
  fill:#666666;
  font:10px sans-serif;
}

text.keyText{
  font:9px 'Raleway',sans-serif;
  color:black;
}
text.keyText.title{

}